@@ -9,12 +9,16 @@ from __future__ import print_function
 
 
 from hamcrest import assert_that
+from hamcrest import calling
 from hamcrest import has_key
 from hamcrest import has_entries
 from hamcrest import is_
+from hamcrest import raises
 
 from zope.dottedname import resolve as dottedname
 
+from nti.schema.interfaces import InvalidValue
+
 from nti.testing.matchers import validly_provides
 from nti.testing.matchers import is_false
 
@@ -54,6 +58,14 @@ TestPlainTextLine = _make_test_class('PlainTextLine')
 TestHTMLContentFragment = _make_test_class('HTMLContentFragment')
 
 
+class TestRstContentFragment(_make_test_class('RstContentFragment')):
+
+    def test_invalid_rst(self):
+        fragment = self._makeOne()
+        assert_that(calling(fragment.fromUnicode).with_args(u".. invalid::"),
+                    raises(InvalidValue, u"Unknown directive"))
+
+
 class TestSanitizedHTMLContentFragment(_make_test_class('SanitizedHTMLContentFragment')):
     def _transform_raw_for_fromUnicode(self, raw):
         result = u'<p>' + raw + '</p>'
